@@ -232,6 +232,7 @@ def _fetch_worms(aphia_id: int) -> pd.DataFrame:
     pandas DataFrame
         Data on the specific species
     """
+    r = None
     try:
         r = requests.get(
             "http://marinespecies.org/rest/AphiaDistributionsByAphiaID/{}".format(
@@ -240,20 +241,19 @@ def _fetch_worms(aphia_id: int) -> pd.DataFrame:
         )
     except Exception as e:
         # no record found for this AphiaID
-        if r.status_code == 204:
+        if r and r.status_code == 204:
             logging.warning(
                 "WoRMS request for AphiaID: {} returned response_"
                 "code 204 - "
-                "No Content.".format(aphia_id)
+                "No Content. Exception: {}".format(aphia_id, e)
             )
         else:
             logging.error(
-                "WoRMS request Error: AphaID: {}, Error: {}, "
-                "Response: {}".format(aphia_id, e, r)
+                "WoRMS request Error: AphaID: {}. Exception: {}".format(aphia_id, e)
             )
         return pd.DataFrame()
     else:
-        if r.status_code == 200:
+        if r and r.status_code == 200:
             logging.info("WoRMS API call SUCCESS for aphia ID: {}".format(aphia_id))
             x = r.json()
             df = pd.DataFrame(x)
@@ -261,8 +261,7 @@ def _fetch_worms(aphia_id: int) -> pd.DataFrame:
             return df
         else:
             logging.warning(
-                "WoRMS API call failed for AphiID: {}, "
-                "reason: {} - {}".format(aphia_id, r.status_code, r.reason)
+                "WoRMS API call failed for AphiID: {}, ".format(aphia_id)
             )
             # returning empty DataFrame will fix error when
             # concatenating them later
