@@ -77,7 +77,7 @@ def read_gisd_worms_link() -> pd.DataFrame:
     df = pd.read_excel(
         os.path.join(
             data_path(),
-            "GISD_and_WoRMS_qualitative_distributions_" "linked_to_MEOWs.xlsx",
+            "GISD_and_WoRMS_qualitative_distributions_linked_to_MEOWs.xlsx",
         ),
         skiprows=5,
         engine="openpyxl",
